# `@salesforce-ux/c360-input-radio`
[![npm (custom registry)](https://img.shields.io/npm/v/@salesforce-ux/c360-input-radio/latest?color=green&label=npm%20package)](https://www.npmjs.com/package/@salesforce-ux/c360-input-radio)

## About
A radio button allows the user to choose only one of a predefined set of mutually exclusive options.

## Getting Started
Let's start by installing `c360-input-radio` as a dependency of your project with [npm](https://www.npmjs.com/package/@salesforce-ux/c360-input-radio).

```
npm i @salesforce-ux/c360-input-radio
```

## Distributable
After installation, all the distributable's for the `c360-input-radio` are found under `/node_modules/@salesforce-ux/c360-input-radio/dist/` folder.

|File Name |Description |
|- |- |
|`input-radio.css` |The CSS file specific to `c360-input-radio` only.|
|`input-radio.compiled.css` |The Compiled CSS file for `c360-input-radio`. This file includes styles of `c360-input-radio`. This file is useful for **LWC** applications.([see below](#for-lightning-web-componentlwc-application) &rarr;)|
|`input-radio.js` |The bundled JS file for `c360-input-radio` component. This file is useful for **Non LWC** applications.([see below](#for-non-lwc-application) &rarr;)|


## `c360-input-radio` Integration

For the sake of understanding, we will categorize the development environment into LWC and Non LWC application.    
This Guide will cover the integration approach for these two types of application.

### For `Lightning Web Component(LWC)` Application

> #### Dependency Inclusion

[`c360-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/c360-styling-hooks) is a styling dependency for `c360-input-radio`. Hence, this needs to be embedded into your web app in order to make the `c360-input-radio` render properly.

```css
/* myComponent.css */
@import "@salesforce-ux/c360-styling-hooks/dist/hooks.custom-props.css";
```

There are also other ways [`c360-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/c360-styling-hooks) can be embedded. Please checkout the [`c360-styling-hooks` Integration Guide](https://www.npmjs.com/package/@salesforce-ux/c360-styling-hooks) to learn more.


> #### Component CSS Import
```css
/* myComponent.css */
@import "@salesforce-ux/c360-styling-hooks/dist/hooks.custom-props.css";
@import '@salesforce-ux/c360-input-radio/dist/input-radio.compiled.css'
```

> #### HTML Decoration
After that,the HTML of your LWC component template needs to be decorated to have all the named part attributes as per the [component's specification](./input-radio.spec.md).
Below is a reference to the component's structure.
```html
<c360-input-radio>
  <div part="input-radio">
    <input type="radio" id="radio-id" part="radio" />
    <label part="label" for="radio-id">
      <span part="indicator"></span>
      <slot></slot>
    </label>
  </div>
</c360-input-radio>
```

### For `Non LWC` Application


> #### Dependency Inclusion [Read the section above](#dependency-inclusion)


> #### Component Import
```JS
/* myComponent.js */
import C360InputRadio from '@salesforce-ux/c360-input-radio/dist/input-radio';
```

> #### Component Registration
```JS
/* myComponent.js */
customElements.define('c360-input-radio', C360InputRadio);
```

#### Example

Below is one approach to integrate your `c360-input-radio` component.
##### Script
```Js
/* myComponent.js */
import '@salesforce-ux/c360-styling-hooks/dist/hooks.custom-props.css';
import C360InputRadio from '@salesforce-ux/c360-input-radio/dist/input-radio';
window.customElements.define('c360-input-radio', C360InputRadio);
```

##### HTML
```html
<c360-input-radio>Radio</c360-input-radio>
```

## Interactive Demo
To see more examples with interactive demo, please visit `c360 Subsystem`'s [Storybook Environment](https://c360-subsystem-storybook.herokuapp.com/?path=/story/c360-subsystem-components-input-radio--base)
